<?php

namespace Drupal\anti_duplicates\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\Node;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\AppendCommand;
use Drupal\Core\Ajax\RemoveCommand;
use Drupal\Core\Url;

/**
 * Hooks all node forms.
 */
class FormAlter {

  /**
   * Search for duplicates based on the title of the node being created.
   */
  public static function duplicatesSearch(array &$form, FormStateInterface $form_state) {

    $config = \Drupal::config('anti_duplicates.settings');

    // Get the node title.
    $title = $form_state->getValue('title')[0]['value'];
    $title = trim($title);
    $title = '%' . str_replace(' ', '%', $title) . '%';

    // Algorithme for searching for similar contents.
    $nids = \Drupal::entityQuery('node')->condition('title', $title, 'LIKE')->execute();
    $nodes = Node::loadMultiple($nids);

    // Add an Ajax response.
    $response = new AjaxResponse();

    // Append a list of found results.
    $response->addCommand(new RemoveCommand('#dw-listing'));
    $response->addCommand(new AppendCommand('#dw_container', '<ul id="dw-listing"></ul>'));

    // List all possible duplicates found.
    foreach ($nodes as $nid => $node) {
      $options = ['absolute' => TRUE];
      $url = Url::fromRoute('entity.node.canonical', ['node' => $nid], $options);
      $url = '<a href="' . $url->toString() . '" title="' . $node->title->value . '" target="_blank">' . $node->title->value . '</a>';
      $response->addCommand(new AppendCommand('#dw-listing', '<li>' . $url . '</li>'));
    }

    /*
    add a link to the anti-duplicates form when the option disable form is
    checked, this link allows the user to enable the form submission by
    agreeing that the content he is writing is unique.
     */
    if ($config->get('anti_duplicates_form_submission')) {
      $response->addCommand(new RemoveCommand('#dw-enable-form'));
      $btn = '<a href="#" class="button" id="dw-enable-form">' . t('not a duplicate') . '</a>';
      $response->addCommand(new AppendCommand('#dw_container', $btn));
    }

    return $response;

  }

}
